@@ -2,8 +2,6 @@ context("Tests Bayesian regression code (rrreg.bayes)")
 
 rm(list=ls())
 
-data(nigeria)
-
 ## Define design parameters
 p <- 2/3  # probability of answering honestly in Forced Response Design
 p1 <- 1/6 # probability of forced 'yes'
@@ -106,7 +104,7 @@ test_that("standard functions coef, sd.rrreg.bayes, summary work", {
   )
   
   expect_output(
-    summary(bayes), "Individual-level predictors"
+    print(summary(bayes)), "Individual-level predictors"
   )
   
   expect_is(
@@ -162,11 +160,11 @@ test_that("doing multiple chains works as well as coef, sd.rrreg.bayes, summary
   summ <- summary(bayes)
   
   expect_output(
-    summ, "Individual-level predictors"
+    print(summ), "Individual-level predictors"
   )
   
   expect_output(
-    summ, "Gelman-Rubin statistics"
+    print(summ), "Gelman-Rubin statistics"
   )
   
 }) 
